env

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 13, 2026 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Get

func Get(t *ast.Task) []string

func GetEnviron

func GetEnviron() *ast.Vars

GetEnviron the all return all environment variables encapsulated on a ast.Vars

func GetFromVars

func GetFromVars(env *ast.Vars) []string

func GetTaskEnv

func GetTaskEnv(key string) string

func GetTaskEnvBool

func GetTaskEnvBool(key string) (bool, bool)

GetTaskEnvBool returns the boolean value of a TASK_ prefixed env var. Returns the value and true if set and valid, or false and false if not set or invalid.

func GetTaskEnvDuration

func GetTaskEnvDuration(key string) (time.Duration, bool)

GetTaskEnvDuration returns the duration value of a TASK_ prefixed env var. Returns the value and true if set and valid, or 0 and false if not set or invalid.

func GetTaskEnvInt

func GetTaskEnvInt(key string) (int, bool)

GetTaskEnvInt returns the integer value of a TASK_ prefixed env var. Returns the value and true if set and valid, or 0 and false if not set or invalid.

func GetTaskEnvString

func GetTaskEnvString(key string) (string, bool)

GetTaskEnvString returns the string value of a TASK_ prefixed env var. Returns the value and true if set (non-empty), or empty string and false if not set.

func GetTaskEnvStringSlice

func GetTaskEnvStringSlice(key string) ([]string, bool)

GetTaskEnvStringSlice returns a comma-separated list from a TASK_ prefixed env var. Returns the slice and true if set (non-empty), or nil and false if not set.

Types

This section is empty.

Jump to