Documentation
¶
Index ¶
- func Get(t *ast.Task) []string
- func GetEnviron() *ast.Vars
- func GetFromVars(env *ast.Vars) []string
- func GetTaskEnv(key string) string
- func GetTaskEnvBool(key string) (bool, bool)
- func GetTaskEnvDuration(key string) (time.Duration, bool)
- func GetTaskEnvInt(key string) (int, bool)
- func GetTaskEnvString(key string) (string, bool)
- func GetTaskEnvStringSlice(key string) ([]string, bool)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetEnviron ¶
GetEnviron the all return all environment variables encapsulated on a ast.Vars
func GetFromVars ¶
func GetTaskEnv ¶
func GetTaskEnvBool ¶
GetTaskEnvBool returns the boolean value of a TASK_ prefixed env var. Returns the value and true if set and valid, or false and false if not set or invalid.
func GetTaskEnvDuration ¶
GetTaskEnvDuration returns the duration value of a TASK_ prefixed env var. Returns the value and true if set and valid, or 0 and false if not set or invalid.
func GetTaskEnvInt ¶
GetTaskEnvInt returns the integer value of a TASK_ prefixed env var. Returns the value and true if set and valid, or 0 and false if not set or invalid.
func GetTaskEnvString ¶
GetTaskEnvString returns the string value of a TASK_ prefixed env var. Returns the value and true if set (non-empty), or empty string and false if not set.
func GetTaskEnvStringSlice ¶
GetTaskEnvStringSlice returns a comma-separated list from a TASK_ prefixed env var. Returns the slice and true if set (non-empty), or nil and false if not set.
Types ¶
This section is empty.